package com.ynet.life.file.parser;

import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonXMLFileParser.class */
public class CommonXMLFileParser implements CommonFileParserInterface {
    private static final String ELEMENT_ROOT = "GZFile";
    private static final String ELEMENT_RECORD_ROOT = "RecordList";
    private static final String ELEMENT_RECORD = "Record";

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding) throws TranFailException {
        XMLWriter writer = null;
        FileOutputStream file = null;
        try {
            try {
                file = new FileOutputStream(filePathName);
                OutputFormat format = new OutputFormat("\t", true, encoding);
                XMLWriter xMLWriter = new XMLWriter(file, format);
                writer = xMLWriter;
                xMLWriter.write(createDocument(recordList, titles, outputFields, outputFormats));
                try {
                    writer.close();
                    file.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (Throwable th) {
                if (writer != null) {
                    try {
                        writer.close();
                    } catch (IOException ex2) {
                        Trace.logError("LifeFile", "I/O异常", ex2);
                        throw new TranFailException("EBLN0000", "I/O异常", ex2);
                    }
                }
                if (file != null) {
                    file.close();
                }
                throw th;
            }
        } catch (IOException ex3) {
            Trace.logError("LifeFile", "文件写入失败", ex3);
            throw new TranFailException("EBLN0000", "文件写入失败", ex3);
        }
    }

    private Document createDocument(List recordList, List titles, List outputFields, List outputFormats) {
        String titleItem;
        Document document = DocumentHelper.createDocument();
        Element recordRoot = document.addElement(ELEMENT_ROOT).addElement(ELEMENT_RECORD_ROOT);
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            KeyedCollection record = (KeyedCollection) iterator.next();
            Element recordElement = recordRoot.addElement(ELEMENT_RECORD);
            for (int i = 0; i < outputFields.size(); i++) {
                String fieldId = (String) outputFields.get(i);
                String str = (String) record.get(fieldId);
                String fieldValue = str;
                if (str == null) {
                    fieldValue = "";
                }
                String format = (String) outputFormats.get(i);
                String fieldValue2 = FileParserUtil.transformFormat(fieldValue, format);
                if (titles != null && (titleItem = (String) titles.get(i)) != null) {
                    fieldId = titleItem;
                }
                recordElement.addElement(fieldId).addText(fieldValue2);
            }
        }
        return document;
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, String expressionContent) throws TranFailException {
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, boolean seqFlag) throws TranFailException {
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List oneTitles, List twoTitles, List recordList, List outputFields, List titleColWidthFormats, List leftRightColMergeFormats, List topBottomColMergeFormats, String filePathName, String encoding, String reportTitle, List leftRightColMergeNum) throws TranFailException {
    }
}
